==> zio-aws-sagemaker_3-5.17.169.1-sources.jar: zio/aws/sagemaker/model/QueryLineageRequest.scala <==
package zio.aws.sagemaker.model
import zio.aws.sagemaker.model.primitives.{
  String8192,
  QueryLineageMaxResults,
  QueryLineageMaxDepth,
  AssociationEntityArn
}
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class QueryLineageRequest(
    startArns: Iterable[AssociationEntityArn],
    direction: Optional[zio.aws.sagemaker.model.Direction] = Optional.Absent,
    includeEdges: Optional[Boolean] = Optional.Absent,
    filters: Optional[zio.aws.sagemaker.model.QueryFilters] = Optional.Absent,
    maxDepth: Optional[QueryLineageMaxDepth] = Optional.Absent,
    maxResults: Optional[QueryLineageMaxResults] = Optional.Absent,
    nextToken: Optional[String8192] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.QueryLineageRequest = {
    import QueryLineageRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.QueryLineageRequest
      .builder()
      .startArns(startArns.map { item =>
        AssociationEntityArn.unwrap(item): java.lang.String
      }.asJavaCollection)
      .optionallyWith(direction.map(value => value.unwrap))(_.direction)
      .optionallyWith(includeEdges.map(value => value: java.lang.Boolean))(
        _.includeEdges
      )
      .optionallyWith(filters.map(value => value.buildAwsValue()))(_.filters)
      .optionallyWith(
        maxDepth.map(value => QueryLineageMaxDepth.unwrap(value): Integer)
      )(_.maxDepth)
      .optionallyWith(
        maxResults.map(value => QueryLineageMaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(
        nextToken.map(value => String8192.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.QueryLineageRequest.ReadOnly =
    zio.aws.sagemaker.model.QueryLineageRequest.wrap(buildAwsValue())
}
object QueryLineageRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.QueryLineageRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.QueryLineageRequest =
      zio.aws.sagemaker.model.QueryLineageRequest(
        startArns,
        direction.map(value => value),
        includeEdges.map(value => value),
        filters.map(value => value.asEditable),
        maxDepth.map(value => value),
        maxResults.map(value => value),
        nextToken.map(value => value)
      )
    def startArns: List[AssociationEntityArn]
    def direction: Optional[zio.aws.sagemaker.model.Direction]
    def includeEdges: Optional[Boolean]
    def filters: Optional[zio.aws.sagemaker.model.QueryFilters.ReadOnly]
    def maxDepth: Optional[QueryLineageMaxDepth]
    def maxResults: Optional[QueryLineageMaxResults]
    def nextToken: Optional[String8192]
    def getStartArns: ZIO[Any, Nothing, List[AssociationEntityArn]] =
      ZIO.succeed(startArns)
    def getDirection: ZIO[Any, AwsError, zio.aws.sagemaker.model.Direction] =
      AwsError.unwrapOptionField("direction", direction)
    def getIncludeEdges: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("includeEdges", includeEdges)
    def getFilters
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.QueryFilters.ReadOnly] =
      AwsError.unwrapOptionField("filters", filters)
    def getMaxDepth: ZIO[Any, AwsError, QueryLineageMaxDepth] =
      AwsError.unwrapOptionField("maxDepth", maxDepth)
    def getMaxResults: ZIO[Any, AwsError, QueryLineageMaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, String8192] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.QueryLineageRequest
  ) extends zio.aws.sagemaker.model.QueryLineageRequest.ReadOnly {
    override val startArns: List[AssociationEntityArn] = impl
      .startArns()
      .asScala
      .map { item =>
        zio.aws.sagemaker.model.primitives.AssociationEntityArn(item)
      }
      .toList
    override val direction: Optional[zio.aws.sagemaker.model.Direction] =
      zio.aws.core.internal
        .optionalFromNullable(impl.direction())
        .map(value => zio.aws.sagemaker.model.Direction.wrap(value))
    override val includeEdges: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.includeEdges())
      .map(value => value: Boolean)
    override val filters
        : Optional[zio.aws.sagemaker.model.QueryFilters.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.filters())
        .map(value => zio.aws.sagemaker.model.QueryFilters.wrap(value))
    override val maxDepth: Optional[QueryLineageMaxDepth] =
      zio.aws.core.internal
        .optionalFromNullable(impl.maxDepth())
        .map(value =>
          zio.aws.sagemaker.model.primitives.QueryLineageMaxDepth(value)
        )
    override val maxResults: Optional[QueryLineageMaxResults] =
      zio.aws.core.internal
        .optionalFromNullable(impl.maxResults())
        .map(value =>
          zio.aws.sagemaker.model.primitives.QueryLineageMaxResults(value)
        )
    override val nextToken: Optional[String8192] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.sagemaker.model.primitives.String8192(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.QueryLineageRequest
  ): zio.aws.sagemaker.model.QueryLineageRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-sagemaker_3-5.20.7.3-sources.jar: zio/aws/sagemaker/model/QueryLineageRequest.scala <==
package zio.aws.sagemaker.model
import zio.aws.sagemaker.model.primitives.{
  String8192,
  QueryLineageMaxResults,
  QueryLineageMaxDepth,
  AssociationEntityArn
}
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class QueryLineageRequest(
    startArns: Optional[Iterable[AssociationEntityArn]] = Optional.Absent,
    direction: Optional[zio.aws.sagemaker.model.Direction] = Optional.Absent,
    includeEdges: Optional[Boolean] = Optional.Absent,
    filters: Optional[zio.aws.sagemaker.model.QueryFilters] = Optional.Absent,
    maxDepth: Optional[QueryLineageMaxDepth] = Optional.Absent,
    maxResults: Optional[QueryLineageMaxResults] = Optional.Absent,
    nextToken: Optional[String8192] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.QueryLineageRequest = {
    import QueryLineageRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.QueryLineageRequest
      .builder()
      .optionallyWith(
        startArns.map(value =>
          value.map { item =>
            AssociationEntityArn.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.startArns)
      .optionallyWith(direction.map(value => value.unwrap))(_.direction)
      .optionallyWith(includeEdges.map(value => value: java.lang.Boolean))(
        _.includeEdges
      )
      .optionallyWith(filters.map(value => value.buildAwsValue()))(_.filters)
      .optionallyWith(
        maxDepth.map(value => QueryLineageMaxDepth.unwrap(value): Integer)
      )(_.maxDepth)
      .optionallyWith(
        maxResults.map(value => QueryLineageMaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(
        nextToken.map(value => String8192.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.QueryLineageRequest.ReadOnly =
    zio.aws.sagemaker.model.QueryLineageRequest.wrap(buildAwsValue())
}
object QueryLineageRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.QueryLineageRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.QueryLineageRequest =
      zio.aws.sagemaker.model.QueryLineageRequest(
        startArns.map(value => value),
        direction.map(value => value),
        includeEdges.map(value => value),
        filters.map(value => value.asEditable),
        maxDepth.map(value => value),
        maxResults.map(value => value),
        nextToken.map(value => value)
      )
    def startArns: Optional[List[AssociationEntityArn]]
    def direction: Optional[zio.aws.sagemaker.model.Direction]
    def includeEdges: Optional[Boolean]
    def filters: Optional[zio.aws.sagemaker.model.QueryFilters.ReadOnly]
    def maxDepth: Optional[QueryLineageMaxDepth]
    def maxResults: Optional[QueryLineageMaxResults]
    def nextToken: Optional[String8192]
    def getStartArns: ZIO[Any, AwsError, List[AssociationEntityArn]] =
      AwsError.unwrapOptionField("startArns", startArns)
    def getDirection: ZIO[Any, AwsError, zio.aws.sagemaker.model.Direction] =
      AwsError.unwrapOptionField("direction", direction)
    def getIncludeEdges: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("includeEdges", includeEdges)
    def getFilters
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.QueryFilters.ReadOnly] =
      AwsError.unwrapOptionField("filters", filters)
    def getMaxDepth: ZIO[Any, AwsError, QueryLineageMaxDepth] =
      AwsError.unwrapOptionField("maxDepth", maxDepth)
    def getMaxResults: ZIO[Any, AwsError, QueryLineageMaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, String8192] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.QueryLineageRequest
  ) extends zio.aws.sagemaker.model.QueryLineageRequest.ReadOnly {
    override val startArns: Optional[List[AssociationEntityArn]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.startArns())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.sagemaker.model.primitives.AssociationEntityArn(item)
          }.toList
        )
    override val direction: Optional[zio.aws.sagemaker.model.Direction] =
      zio.aws.core.internal
        .optionalFromNullable(impl.direction())
        .map(value => zio.aws.sagemaker.model.Direction.wrap(value))
    override val includeEdges: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.includeEdges())
      .map(value => value: Boolean)
    override val filters
        : Optional[zio.aws.sagemaker.model.QueryFilters.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.filters())
        .map(value => zio.aws.sagemaker.model.QueryFilters.wrap(value))
    override val maxDepth: Optional[QueryLineageMaxDepth] =
      zio.aws.core.internal
        .optionalFromNullable(impl.maxDepth())
        .map(value =>
          zio.aws.sagemaker.model.primitives.QueryLineageMaxDepth(value)
        )
    override val maxResults: Optional[QueryLineageMaxResults] =
      zio.aws.core.internal
        .optionalFromNullable(impl.maxResults())
        .map(value =>
          zio.aws.sagemaker.model.primitives.QueryLineageMaxResults(value)
        )
    override val nextToken: Optional[String8192] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.sagemaker.model.primitives.String8192(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.QueryLineageRequest
  ): zio.aws.sagemaker.model.QueryLineageRequest.ReadOnly = new Wrapper(impl)
}
